pub fn parse_instructions_toml(source: &str) -> Result<InstructionsTable, Error>Expand description
Parse TOML source into an InstructionsTable.
Errors
Returns a TOML deserialization error when source is invalid or does not match the schema.
pub fn parse_instructions_toml(source: &str) -> Result<InstructionsTable, Error>Parse TOML source into an InstructionsTable.
Returns a TOML deserialization error when source is invalid or does not match the schema.